interface IEdge {
    /**
     * The other end of the edge.
     */
    to: number;
    /**
     * The cost of walking along this side.
     */
    cost: bigint;
}
interface IGraph {
    /**
     * The number of nodes in the graph. (0-index)
     */
    N: number;
    /**
     * The source node. (0-index)
     */
    source: number;
    /**
     * Graph edges.
     */
    edges: ReadonlyArray<IEdge>;
    /**
     * Adjacency list. G[i] represent the index list of the  edges start from node i.
     */
    G: ReadonlyArray<ReadonlyArray<number>>;
    /**
     * An array recording the shortest distance to the source point.
     */
    dist?: bigint[];
}
interface IOptions {
    /**
     * A big number, representing the unreachable cost.
     */
    INF?: bigint;
}
/**
 * The dijkstra algorithm (bigint version), optimized with priority queue.
 *
 * @param graph
 * @param options
 * @see https://me.guanghechen.com/post/algorithm/graph/shortest-path/dijkstra
 * @see https://github.com/guanghechen/algorithm.ts/tree/release-2.x.x/packages/dijkstra
 */
declare function dijkstra(graph: IGraph, options?: IOptions): bigint[];

export { IEdge, IGraph, IOptions, dijkstra as default, dijkstra };
